@@ -2,6 +2,7 @@
 //! the instructions that are sent between threads.
 
 use crate::channels::{SenderWithContext, ASYNCOPENCALLS, OPENCALLS};
+use colored::*;
 use serde::{Deserialize, Serialize};
 use std::fmt::{Display, Error, Formatter};
 use std::panic::PanicInfo;
@@ -104,7 +105,7 @@ pub fn get_current_ctx() -> ErrorContext {
 }
 
 /// A representation of the call stack.
-#[derive(Clone, Copy, Serialize, Deserialize)]
+#[derive(Clone, Copy, Serialize, Deserialize, Debug)]
 pub struct ErrorContext {
     calls: [ContextType; MAX_THREAD_CALL_STACK],
 }
@@ -120,8 +121,8 @@ impl ErrorContext {
 
     /// Adds a call to this [`ErrorContext`]'s call stack representation.
     pub fn add_call(&mut self, call: ContextType) {
-        for ctx in self.calls.iter_mut() {
-            if *ctx == ContextType::Empty {
+        for ctx in &mut self.calls {
+            if let ContextType::Empty = ctx {
                 *ctx = call;
                 break;
             }
@@ -161,7 +162,7 @@ impl Display for ErrorContext {
 /// Complex variants store a variant of a related enum, whose variants can be built from
 /// the corresponding Zellij MSPC instruction enum variants ([`ScreenInstruction`],
 /// [`PtyInstruction`], [`ClientInstruction`], etc).
-#[derive(Copy, Clone, PartialEq, Serialize, Deserialize)]
+#[derive(Copy, Clone, PartialEq, Serialize, Deserialize, Debug)]
 pub enum ContextType {
     /// A screen-related call.
     Screen(ScreenContext),
@@ -180,24 +181,21 @@ pub enum ContextType {
     Empty,
 }
 
-// TODO use the `colored` crate for color formatting
 impl Display for ContextType {
     fn fmt(&self, f: &mut Formatter) -> Result<(), Error> {
-        let purple = "\u{1b}[1;35m";
-        let green = "\u{1b}[0;32m";
-        match *self {
-            ContextType::Screen(c) => write!(f, "{}screen_thread: {}{:?}", purple, green, c),
-            ContextType::Pty(c) => write!(f, "{}pty_thread: {}{:?}", purple, green, c),
-            ContextType::Plugin(c) => write!(f, "{}plugin_thread: {}{:?}", purple, green, c),
-            ContextType::Client(c) => write!(f, "{}main_thread: {}{:?}", purple, green, c),
-            ContextType::IPCServer(c) => write!(f, "{}ipc_server: {}{:?}", purple, green, c),
-            ContextType::StdinHandler => {
-                write!(f, "{}stdin_handler_thread: {}AcceptInput", purple, green)
-            }
-            ContextType::AsyncTask => {
-                write!(f, "{}stream_terminal_bytes: {}AsyncTask", purple, green)
-            }
-            ContextType::Empty => write!(f, ""),
+        if let Some((left, right)) = match *self {
+            ContextType::Screen(c) => Some(("screen_thread:", format!("{:?}", c))),
+            ContextType::Pty(c) => Some(("pty_thread:", format!("{:?}", c))),
+            ContextType::Plugin(c) => Some(("plugin_thread:", format!("{:?}", c))),
+            ContextType::Client(c) => Some(("main_thread:", format!("{:?}", c))),
+            ContextType::IPCServer(c) => Some(("ipc_server:", format!("{:?}", c))),
+            ContextType::StdinHandler => Some(("stdin_handler_thread:", "AcceptInput".to_string())),
+            ContextType::AsyncTask => Some(("stream_terminal_bytes:", "AsyncTask".to_string())),
+            ContextType::Empty => None,
+        } {
+            write!(f, "{} {}", left.purple(), right.green())
+        } else {
+            write!(f, "")
         }
     }
 }
@@ -209,6 +207,8 @@ pub enum ScreenContext {
     HandlePtyBytes,
     Render,
     NewPane,
+    ToggleFloatingPanes,
+    TogglePaneEmbedOrFloating,
     HorizontalSplit,
     VerticalSplit,
     WriteCharacter,
@@ -216,6 +216,8 @@ pub enum ScreenContext {
     ResizeRight,
     ResizeDown,
     ResizeUp,
+    ResizeIncrease,
+    ResizeDecrease,
     SwitchFocus,
     FocusNextPane,
     FocusPreviousPane,
@@ -226,6 +228,11 @@ pub enum ScreenContext {
     MoveFocusUp,
     MoveFocusRight,
     MoveFocusRightOrNextTab,
+    MovePane,
+    MovePaneDown,
+    MovePaneUp,
+    MovePaneRight,
+    MovePaneLeft,
     Exit,
     ScrollUp,
     ScrollUpAt,
@@ -234,6 +241,8 @@ pub enum ScreenContext {
     ScrollToBottom,
     PageScrollUp,
     PageScrollDown,
+    HalfPageScrollUp,
+    HalfPageScrollDown,
     ClearScroll,
     CloseFocusedPane,
     ToggleActiveSyncTab,
@@ -244,7 +253,7 @@ pub enum ScreenContext {
     SetFixedHeight,
     SetFixedWidth,
     ClosePane,
-    ApplyLayout,
+    UpdatePaneName,
     NewTab,
     SwitchTabNext,
     SwitchTabPrev,
@@ -254,10 +263,17 @@ pub enum ScreenContext {
     TerminalResize,
     ChangeMode,
     LeftClick,
+    RightClick,
     MouseRelease,
     MouseHold,
     Copy,
     ToggleTab,
+    AddClient,
+    RemoveClient,
+    AddOverlay,
+    RemoveOverlay,
+    ConfirmPrompt,
+    DenyPrompt,
 }
 
 /// Stack call representations corresponding to the different types of [`PtyInstruction`]s.
@@ -267,6 +283,7 @@ pub enum PtyContext {
     SpawnTerminalVertically,
     SpawnTerminalHorizontally,
     UpdateActivePane,
+    GoToTab,
     NewTab,
     ClosePane,
     CloseTab,
@@ -281,6 +298,8 @@ pub enum PluginContext {
     Render,
     Unload,
     Exit,
+    AddClient,
+    RemoveClient,
 }
 
 /// Stack call representations corresponding to the different types of [`ClientInstruction`]s.
@@ -292,6 +311,7 @@ pub enum ClientContext {
     Render,
     ServerError,
     SwitchToMode,
+    Connected,
 }
 
 /// Stack call representations corresponding to the different types of [`ServerInstruction`]s.
@@ -303,6 +323,8 @@ pub enum ServerContext {
     ClientExit,
     RemoveClient,
     Error,
+    KillSession,
     DetachSession,
     AttachClient,
+    ConnStatus,
 }
